Module: Declarative::Builder::Build
- Defined in:
- lib/declarative/builder.rb
Instance Method Summary collapse
-
#build!(context, *args, **options) ⇒ Object
Call this from your class to compute the concrete target class.
Instance Method Details
#build!(context, *args, **options) ⇒ Object
Call this from your class to compute the concrete target class.
36 37 38 |
# File 'lib/declarative/builder.rb', line 36 def build!(context, *args, **) builders.(context, *args, **) end |